/**
 * Each one of the arguments bellow, excluding 'checked_rows', can set the action to be visible on 'edit', 'list' and 'view':
 * - In the arguments 'never' and 'back', just add a '_edit', '_list' or '_view'.
 * - In the argument 'always', just overwrite it for 'edit', 'list' or 'view'.
 * 
 * More than one argument can be set putting a '|'.
 * @namespace   showAsAction
 * @memberof    module:actions
 * @property  {String} always - Visible in the middle of the context.
 * @property  {String} back - Visible in the left of the context.
 * @property  {String} never - Visible in the right of the context.
 * @property  {String} checked_rows - Visible when rows are checked.
 * @example
  
    "actions": [

        //Action present only in edit
        {
            "id": "3935187193502408010477",
            "name": "back",
            "label": "Back",
            "showAsAction": "back_edit",
            "events": [
                {
                    "id": "393518719534273360398",
                    "name": "ActionEvent",
                    "code": "Util.back();"
                }
            ]
        },
    
        //Action present in the edit and view
        {
            "id": "3935187193502408010477",
            "name": "back",
            "label": "Back",
            "showAsAction": "back_view|back_edit",
            "events": [
                {
                    "id": "393518719534273360398",
                    "name": "ActionEvent",
                    "code": "Util.back();"
                }
            ]
        }
    ]   
 */ 